@@ -56,16 +56,13 @@ class AnnotationMixin(Element):
         """Return all the annotations that match the criteria.
 
         Args:
+            creator (str, optional): The creator of the annotation.
+            start_date (datetime, optional): The start date for filtering.
+            end_date (datetime, optional): The end date for filtering.
+            content (str, optional): A regex to match in the content.
 
-            creator -- str
-
-            start_date -- datetime instance
-
-            end_date --  datetime instance
-
-            content -- str regex
-
-        Returns: list of Annotation
+        Returns:
+            list[Annotation]: A list of matching Annotation elements.
         """
         annotations: list[Annotation] = []
         for annotation in cast(
@@ -97,20 +94,15 @@ class AnnotationMixin(Element):
         """Return the annotation that matches the criteria.
 
         Args:
+            position (int, optional): The position of the annotation to return.
+            creator (str, optional): The creator of the annotation.
+            start_date (datetime, optional): The start date for filtering.
+            end_date (datetime, optional): The end date for filtering.
+            content (str, optional): A regex to match in the content.
+            name (str, optional): The name of the annotation.
 
-            position -- int
-
-            creator -- str
-
-            start_date -- datetime instance
-
-            end_date -- datetime instance
-
-            content -- str regex
-
-            name -- str
-
-        Returns: Annotation or None if not found
+        Returns:
+            Annotation or None: The matching Annotation element, or None if not found.
         """
         if name is not None:
             return cast(
@@ -138,7 +130,8 @@ class AnnotationMixin(Element):
     def get_annotation_ends(self) -> list[AnnotationEnd]:
         """Return all the annotation ends.
 
-        Returns: list of AnnotationEnd
+        Returns:
+            list[AnnotationEnd]: A list of AnnotationEnd elements.
         """
         return cast(
             list[AnnotationEnd],
@@ -155,12 +148,11 @@ class AnnotationMixin(Element):
         """Return the annotation end that matches the criteria.
 
         Args:
+            position (int, optional): The position of the annotation end to return.
+            name (str, optional): The name of the annotation end.
 
-            position -- int
-
-            name -- str
-
-        Returns: AnnotationEnd or None if not found
+        Returns:
+            AnnotationEnd or None: The matching AnnotationEnd element, or None if not found.
         """
         return cast(
             Union[None, AnnotationEnd],
@@ -171,7 +163,14 @@ class AnnotationMixin(Element):
 
 
 def get_unique_office_name(element: Element | None = None) -> str:
-    """Provide an autogenerated unique "office:name" for the document."""
+    """Provide an autogenerated unique "office:name" for the document.
+
+    Args:
+        element (Element, optional): The element to which the annotation is related.
+
+    Returns:
+        str: A unique name.
+    """
     if element is not None:
         body = element.document_body
     else:
@@ -194,7 +193,18 @@ def get_unique_office_name(element: Element | None = None) -> str:
 
 
 class Annotation(MDTail, Element, DcCreatorMixin, DcDateMixin):
-    """An annotation (private note), "text:annotation"."""
+    """An annotation (private note), "office:annotation".
+
+    This element contains the content of a comment or annotation, along with
+    metadata such as the creator and date.
+
+    Attributes:
+        name (str): The unique name of the annotation.
+        note_id (str): The ID of the note.
+        creator (str): The creator of the annotation.
+        date (datetime): The date of the annotation.
+        note_body (str or Element): The body content of the annotation.
+    """
 
     _tag = "office:annotation"
     _properties = (
@@ -211,24 +221,26 @@ class Annotation(MDTail, Element, DcCreatorMixin, DcDateMixin):
         parent: Element | None = None,
         **kwargs: Any,
     ) -> None:
-        """An annotation (private note), "text:annotation".
+        """Create an Annotation element.
 
-        Annotation element credited to the given creator with the
-        given text, optionally dated (current date by default).
-        If name not provided and some parent is provided, the name is
-        autogenerated.
+        An annotation is a private note, represented by "office:annotation".
+        This element is credited to a creator and contains text content,
+        optionally dated (current date by default).
+
+        If 'name' is not provided and a 'parent' is given, the name will be
+        autogenerated to be unique within the document.
 
         Args:
-
-            text -- str or odf_element
-
-            creator -- str
-
-            date -- datetime
-
-            name -- str
-
-            parent -- Element
+            text_or_element (Element or str, optional): The content of the
+                annotation, which can be a string or another ODF element.
+            creator (str, optional): The name of the person who created the
+                annotation.
+            date (datetime, optional): The date and time when the annotation
+                was created. Defaults to the current time if not provided.
+            name (str, optional): A unique name for the annotation. If not
+                provided, a unique name is generated.
+            parent (Element, optional): The parent element to which this
+                annotation will be associated for name generation.
         """
         # fixme : use offset
         # TODO allow paragraph and text styles
@@ -304,22 +316,22 @@ class Annotation(MDTail, Element, DcCreatorMixin, DcDateMixin):
     ) -> Element | list | str | None:
         """Returns the annotated content from an annotation.
 
-        If no content exists (single position annotation or annotation-end not
-        found), returns [] (or "" if text flag is True).
-        If as_text is True: returns the text content.
-        If clean is True: suppress unwanted tags (deletions marks, ...)
-        If no_header is True: existing text:h are changed in text:p
-        By default: returns a list of odf_element, cleaned and without headers.
+        If no content exists (e.g., single position annotation or if the
+        annotation-end tag is not found), it returns an empty list or an
+        empty string if 'as_text' is True.
 
         Args:
+            as_text (bool): If True, returns the text content as a string.
+                            Defaults to False.
+            no_header (bool): If True, converts 'text:h' elements to 'text:p'.
+                              Defaults to True.
+            clean (bool): If True, suppresses unwanted tags such as deletion
+                          marks. Defaults to True.
 
-            as_text -- boolean
-
-            clean -- boolean
-
-            no_header -- boolean
-
-        Returns: list or Element or text or None
+        Returns:
+            Element | list | str | None: The content of the annotation, which
+            can be a single element, a list of elements, a string, or None if
+            the end tag is missing.
         """
         end = self.end
         if end is None:
@@ -332,15 +344,17 @@ class Annotation(MDTail, Element, DcCreatorMixin, DcDateMixin):
         )
 
     def delete(self, child: Element | None = None, keep_tail: bool = True) -> None:
-        """Delete the given element from the XML tree. If no element is given,
-        "self" is deleted. The XML library may allow to continue to use an
-        element now "orphan" as long as you have a reference to it.
+        """Delete the element from the XML tree.
 
-        For Annotation : delete the annotation-end tag if exists.
+        If a child element is provided, it is deleted. If no child is given,
+        the annotation itself and its corresponding "annotation-end" tag
+        (if it exists) are deleted.
 
         Args:
-
-            child -- Element or None
+            child (Element, optional): The child element to delete. If None,
+                the annotation itself is deleted. Defaults to None.
+            keep_tail (bool): This argument is not used in this context but is
+                kept for compatibility. Defaults to True.
         """
         if child is not None:  # act like normal delete
             super().delete(child)
@@ -369,15 +383,18 @@ Annotation._define_attribut_property()
 class AnnotationEnd(MDTail, Element):
     """End of annotation marker, "office:annotation-end".
 
-    AnnotationEnd: the "office:annotation-end" element may be used to
-    define the end of a text range of document content that spans element
-    boundaries. In that case, an "office:annotation" element shall precede
-    the "office:annotation-end" element. Both elements shall have the same
-    value for their office:name attribute. The "office:annotation-end" element
-    shall be preceded by an "office:annotation" element that has the same
-    value for its office:name attribute as the "office:annotation-end"
-    element. An "office:annotation-end" element without a preceding
-    "office:annotation" element that has the same name assigned is ignored.
+    The "office:annotation-end" element is used to define the end of a text
+    range that is being annotated, especially when the content spans across
+    element boundaries. It must be preceded by an "office:annotation" element
+    with the same 'office:name' attribute.
+
+    If an "office:annotation-end" element does not have a matching preceding
+    "office:annotation" element, it is ignored.
+
+    Attributes:
+        name (str): The name of the annotation this element is closing. This
+                    name must match the 'office:name' of a preceding
+                    "office:annotation" element.
     """
 
     _tag = "office:annotation-end"
@@ -389,24 +406,18 @@ class AnnotationEnd(MDTail, Element):
         name: str | None = None,
         **kwargs: Any,
     ) -> None:
-        """An annotation (private note), "text:annotation".
+        """Create an AnnotationEnd element.
 
-        Annotation element credited to the given creator with the
-        given text, optionally dated (current date by default).
-        If name not provided and some parent is provided, the name is
-        autogenerated.
+        This element marks the end of an annotation. It must be associated
+        with an existing "office:annotation" element, either by passing the
+        annotation object directly or by providing a matching name.
 
         Args:
-
-            text -- str or odf_element
-
-            creator -- str
-
-            date -- datetime
-
-            name -- str
-
-            parent -- Element
+            annotation (Annotation, optional): The "office:annotation" element
+                that this "annotation-end" is closing. If provided, the 'name'
+                attribute will be taken from this annotation.
+            name (str, optional): The name of the annotation to close. This is
+                required if 'annotation' is not provided.
         """
         # fixme : use offset
         # TODO allow paragraph and text styles
