@@ -37,10 +37,23 @@ DURATION_FORMAT = "PT%02dH%02dM%02dS"
 
 
 class Boolean:
-    """Conversion between ODF boolean format and Python bool."""
+    """Handles conversion between ODF boolean string representation ('true', 'false')
+    and Python's native `bool` type.
+    """
 
     @staticmethod
     def decode(data: str) -> bool:
+        """Decode an ODF boolean string to a Python boolean.
+
+        Args:
+            data (str): The string to decode, expected to be 'true' or 'false'.
+
+        Returns:
+            bool: `True` if data is 'true', `False` if data is 'false'.
+
+        Raises:
+            ValueError: If the input string is not a valid ODF boolean ('true' or 'false').
+        """
         if data == "true":
             return True
         elif data == "false":
@@ -49,6 +62,18 @@ class Boolean:
 
     @staticmethod
     def encode(value: bool | str | bytes) -> str:
+        """Encode a Python boolean (or boolean-like string/bytes) to an ODF boolean string.
+
+        Args:
+            value (bool | str | bytes): The value to encode. Can be a Python `bool`,
+                a string ('true', 'false' case-insensitive), or bytes.
+
+        Returns:
+            str: The ODF boolean string ('true' or 'false').
+
+        Raises:
+            TypeError: If the input value cannot be interpreted as a boolean.
+        """
         if isinstance(value, bytes):
             value = value.decode()
         if value is True or str(value).lower() == "true":
@@ -59,15 +84,34 @@ class Boolean:
 
 
 class Date:
-    """Conversion between ODF date formats and Python datetime."""
+    """Handles conversion between ODF date string representation and Python's `datetime.date` type.
+    Assumes ISO 8601 format (YYYY-MM-DD) for ODF dates.
+    """
 
     @staticmethod
     def decode(data: str) -> datetime:
+        """Decode an ODF date string to a Python `datetime` object.
+
+        Args:
+            data (str): The date string to decode, expected in ISO 8601 format (YYYY-MM-DD).
+
+        Returns:
+            datetime: A `datetime` object representing the decoded date.
+        """
         return datetime.fromisoformat(data)
 
     @staticmethod
     def encode(value: datetime | date) -> str:
-        """Return text formatted as "2024-01-31"."""
+        """Encode a Python `datetime` or `date` object to an ODF date string.
+
+        The output string is formatted as "YYYY-MM-DD".
+
+        Args:
+            value (datetime | date): The `datetime` or `date` object to encode.
+
+        Returns:
+            str: The ODF date string (e.g., "2024-01-31").
+        """
         if isinstance(value, datetime):
             return value.date().isoformat()
         # date instance
@@ -75,10 +119,24 @@ class Date:
 
 
 class DateTime:
-    """Conversion between ODF date/hour formats and Python datetime."""
+    """Handles conversion between ODF date-time string representation and Python's `datetime.datetime` type.
+    Assumes ISO 8601 format for ODF date-times.
+    """
 
     @staticmethod
     def decode(data: str) -> datetime:
+        """Decode an ODF date-time string to a Python `datetime.datetime` object.
+
+        Handles various ISO 8601 formats and provides compatibility for Python 3.9/3.10
+        specific `fromisoformat` behaviors.
+
+        Args:
+            data (str): The date-time string to decode, expected in ISO 8601 format.
+
+        Returns:
+            datetime: A `datetime.datetime` object representing the decoded date-time.
+        """
+
         def _decode_39_310(data1: str) -> datetime:  # pragma: nocover
             if data1.endswith("Z"):
                 data1 = data1[:-1] + "+00:00"
@@ -104,6 +162,17 @@ class DateTime:
 
     @staticmethod
     def encode(value: datetime) -> str:
+        """Encode a Python `datetime.datetime` object to an ODF date-time string.
+
+        The output string is formatted in ISO 8601. UTC offsets (e.g., "+00:00")
+        are converted to the canonical 'Z' representation.
+
+        Args:
+            value (datetime): The `datetime.datetime` object to encode.
+
+        Returns:
+            str: The ODF date-time string (e.g., "YYYY-MM-DDTHH:MM:SSZ").
+        """
         text = value.isoformat()
         if text.endswith("+00:00"):
             # convert to canonical representation
@@ -112,12 +181,23 @@ class DateTime:
 
 
 class Duration:
-    """Conversion between ODF duration (ISO8601 format) and Python
-    timedelta.
+    """Handles conversion between ODF duration string representation (ISO 8601 format)
+    and Python's `datetime.timedelta` type.
     """
 
     @staticmethod
     def decode(data: str) -> timedelta:
+        """Decode an ODF duration string (ISO 8601) to a Python `datetime.timedelta` object.
+
+        Args:
+            data (str): The duration string to decode (e.g., "PT1H30M0S", "-P5D").
+
+        Returns:
+            timedelta: A `datetime.timedelta` object representing the decoded duration.
+
+        Raises:
+            ValueError: If the input string is not a valid ISO 8601 duration format.
+        """
         if data.startswith("P"):
             sign = 1
         elif data.startswith("-P"):
@@ -159,6 +239,17 @@ class Duration:
 
     @staticmethod
     def encode(value: timedelta) -> str:
+        """Encode a Python `datetime.timedelta` object to an ODF duration string (ISO 8601).
+
+        Args:
+            value (timedelta): The `datetime.timedelta` object to encode.
+
+        Returns:
+            str: The ODF duration string (e.g., "PT1H30M0S", "-P5D").
+
+        Raises:
+            TypeError: If the input value is not a `datetime.timedelta` object.
+        """
         if not isinstance(value, timedelta):
             raise TypeError(f"duration must be a timedelta: {value!r}")
 
