@@ -27,7 +27,7 @@ from typing import Any
 
 from .annotation import AnnotationMixin
 from .bookmark import BookmarkMixin
-from .element import Element, PropDef, register_element_class
+from .element import Element, PropDef, PropDefBool, register_element_class
 from .mixin_md import MDLink
 from .mixin_paragraph_formatted import ParaFormattedTextMixin
 from .note import NoteMixin
@@ -43,10 +43,20 @@ class Link(
     NoteMixin,
     Element,
 ):
-    """Representation of a link (URL), "text:a"."""
+    """Representation of a link (URL), "text:a".
+
+    Attributes:
+        url: target url (href)
+        name: name (html name)
+        title: title (hint)
+        text: link text
+        target_frame: '_self', '_blank', '_parent', '_top'
+        style: style name
+        visited_style: visited style name
+    """
 
     _tag = "text:a"
-    _properties: tuple[PropDef, ...] = (
+    _properties: tuple[PropDef | PropDefBool, ...] = (
         PropDef("url", "xlink:href"),
         PropDef("name", "office:name"),
         PropDef("title", "office:title"),
@@ -67,23 +77,16 @@ class Link(
         visited_style: str | None = None,
         **kwargs: Any,
     ) -> None:
-        """Representation of a link (URL), "text:a".
+        """Create a Link, "text:a"
 
         Args:
-
-            url -- str
-
-            name -- str
-
-            title -- str
-
-            text -- str
-
-            target_frame -- '_self', '_blank', '_parent', '_top'
-
-            style -- str
-
-            visited_style -- str
+            url: target url (href)
+            name: name (html name)
+            title: title (hint)
+            text: link text
+            target_frame: '_self', '_blank', '_parent', '_top'
+            style: style name
+            visited_style: visited style name
         """
         super().__init__(**kwargs)
         if self._do_init:
