@@ -18,6 +18,12 @@
 # The odfdo project is a derivative work of the lpod-python project:
 # https://github.com/lpod/lpod-python
 # Authors: David Versmisse <david.versmisse@itaapy.com>
+"""Command-line script to show the differences between two ODT files.
+
+This script compares the textual content of two ODT documents and displays
+the differences in either a standard unified diff format or an ndiff format.
+"""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser, Namespace
@@ -31,8 +37,15 @@ PROG = "odfdo-diff"
 
 
 def configure_parser() -> ArgumentParser:
-    description = "Show a diff between two .odt files."
-    parser = ArgumentParser(prog=PROG, description=description)
+    description = (
+        "Show a diff between the textual content of two ODT files. "
+        "By default, the output is in the unified diff format."
+    )
+    epilog = (
+        "This tool is useful for comparing two versions of a document "
+        "and tracking changes in its textual content."
+    )
+    parser = ArgumentParser(prog=PROG, description=description, epilog=epilog)
     parser.add_argument(
         "-n",
         "--ndiff",
