@@ -18,6 +18,13 @@
 # The odfdo project is a derivative work of the lpod-python project:
 # https://github.com/lpod/lpod-python
 # Authors: Jerome Dumonteil <jerome.dumonteil@itaapy.com>
+"""Command-line script to convert ODF files to/from a folder structure.
+
+This script allows for converting a standard ODF file (which is a zip archive)
+into a directory containing its component XML files and assets, and vice-versa.
+This is useful for version control and manual inspection of ODF documents.
+"""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser, Namespace
@@ -30,8 +37,16 @@ PROG = "odfdo-folder"
 
 
 def configure_parser() -> ArgumentParser:
-    description = "Convert standard ODF file to folder, and reverse."
-    parser = ArgumentParser(prog=PROG, description=description)
+    description = (
+        "Convert a standard ODF file (zip archive) to a folder "
+        "structure, or convert a folder structure back to an ODF file."
+    )
+    epilog = (
+        "This tool is useful for version control and manual inspection "
+        "of ODF documents, as it allows access to the component XML files "
+        "and assets within the ODF package."
+    )
+    parser = ArgumentParser(prog=PROG, description=description, epilog=epilog)
     parser.add_argument(
         "--version",
         action="version",
