@@ -17,6 +17,13 @@
 # Authors (odfdo project): jerome.dumonteil@gmail.com
 # The odfdo project is a derivative work of the lpod-python project:
 # https://github.com/lpod/lpod-python
+"""Command-line script to export a table from an ODF spreadsheet to CSV.
+
+This script extracts a specified table (or the first table by default) from
+an ODS file and converts it to a CSV format, outputting to a file or
+standard output.
+"""
+
 from __future__ import annotations
 
 import sys
@@ -29,8 +36,16 @@ PROG = "odfdo-to-csv"
 
 
 def configure_parser() -> ArgumentParser:
-    description = "Export a .ods table to a CSV file."
-    epilog = "Minimal-featured CSV exporter based on the Python CSV module."
+    description = (
+        "Export a table from an ODS (OpenDocument Spreadsheet) file to a CSV file. "
+        "The script extracts a specified table (or the first table by default) "
+        "and converts its content into CSV format."
+    )
+    epilog = (
+        "This tool provides a basic CSV exporter, leveraging the Python CSV module's "
+        "functionality. It can output to a file or standard output. "
+        "You can choose between 'excel' (default) or 'unix' CSV dialects."
+    )
     parser = ArgumentParser(prog=PROG, description=description, epilog=epilog)
     parser.add_argument(
         "--version",
