@@ -17,6 +17,12 @@
 # Authors (odfdo project): jerome.dumonteil@gmail.com
 # The odfdo project is a derivative work of the lpod-python project:
 # https://github.com/lpod/lpod-python
+"""Command-line script to convert an ODF text document to Markdown.
+
+This script reads an ODF text document and prints its content to standard
+output in Markdown format.
+"""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser, Namespace
@@ -28,8 +34,15 @@ PROG = "odfdo-markdown"
 
 
 def configure_parser() -> ArgumentParser:
-    description = "Export text document in markdown format to stdout."
-    parser = ArgumentParser(prog=PROG, description=description)
+    description = (
+        "Convert an ODF text document to Markdown format and print to standard output."
+    )
+    epilog = (
+        "This tool is useful for extracting the textual content of an ODF "
+        "document in a lightweight, human-readable, and version-control-friendly "
+        "format. It processes the document's main body content."
+    )
+    parser = ArgumentParser(prog=PROG, description=description, epilog=epilog)
     parser.add_argument(
         "--version",
         action="version",
